@@ -20,10 +20,20 @@ class Synapse(ABC):
     request_type = None
 
     def __init__(self, raw_request: Request) -> None:
-        self.raw_request = raw_request
-        self.request = Request.parse_raw(self.raw_request)
-        self.connection = self.request.connection
-        self.request_type = self.request.type
+        self.raw_request = Request.parse_raw(raw_request)
+        self.request_type = self.raw_request.type
+        self.connection = self.raw_request.connection
+        self.request = self.__set_request()
+
+    def __set_request(self):
+        if self.request_type == RequestType.DESCRIBE:
+            return DescribeRequest.parse_obj(self.raw_request.body)
+        elif self.request_type in [RequestType.READ, RequestType.GET, RequestType.CREATE, RequestType.UPDATE, RequestType.DELETE]:
+            return SyncRequest.parse_obj(self.raw_request.body)
+        elif self.request_type in [RequestType.EXTRACT_WEBHOOK_IDENTIFIER, RequestType.PROCESS_WEBHOOK]:
+            return WebhookRequest.parse_obj(self.raw_request.body)
+        else:
+            return self.raw_request
 
     def execute(self):
         """
@@ -44,7 +54,6 @@ class Synapse(ABC):
                     raise self.__prep_invalid_response_exception(response)
 
             elif self.request_type == RequestType.DESCRIBE:
-                self.request = DescribeRequest.parse_obj(self.request.body)
                 response = self.describe()
                 if not isinstance(response, list):
                     raise self.__prep_invalid_response_exception(response)
@@ -53,13 +62,11 @@ class Synapse(ABC):
                         raise self.__prep_invalid_response_exception(response)
 
             elif self.request_type == RequestType.READ:
-                self.request = SyncRequest.parse_obj(self.request.body)
                 response = self.read()
                 if not isinstance(response, ReadResponse):
                     raise self.__prep_invalid_response_exception(response)
 
             elif self.request_type == RequestType.GET:
-                self.request = SyncRequest.parse_obj(self.request.body)
                 response = self.get()
                 if not isinstance(response, list):
                     raise self.__prep_invalid_response_exception(response)
@@ -68,7 +75,6 @@ class Synapse(ABC):
                         raise self.__prep_invalid_response_exception(response)
 
             elif self.request_type == RequestType.CREATE:
-                self.request = SyncRequest.parse_obj(self.request.body)
                 response = self.create()
                 if not isinstance(response, list):
                     raise self.__prep_invalid_response_exception(response)
@@ -77,7 +83,6 @@ class Synapse(ABC):
                         raise self.__prep_invalid_response_exception(response)
 
             elif self.request_type == RequestType.UPDATE:
-                self.request = SyncRequest.parse_obj(self.request.body)
                 response = self.update()
                 if not isinstance(response, list):
                     raise self.__prep_invalid_response_exception(response)
@@ -86,7 +91,6 @@ class Synapse(ABC):
                         raise self.__prep_invalid_response_exception(response)
 
             elif self.request_type == RequestType.DELETE:
-                self.request = SyncRequest.parse_obj(self.request.body)
                 response = self.delete()
                 if not isinstance(response, list):
                     raise self.__prep_invalid_response_exception(response)
@@ -95,13 +99,11 @@ class Synapse(ABC):
                         raise self.__prep_invalid_response_exception(response)
 
             elif self.request_type == RequestType.EXTRACT_WEBHOOK_IDENTIFIER:
-                self.request = WebhookRequest.parse_obj(self.request.body)
                 response = self.extract_webhook_identifier()
                 if not isinstance(response, str):
                     raise self.__prep_invalid_response_exception(response)
 
             elif self.request_type == RequestType.PROCESS_WEBHOOK:
-                self.request = WebhookRequest.parse_obj(self.request.body)
                 response = self.process_webhook()
                 if not isinstance(response, list):
                     raise self.__prep_invalid_response_exception(response)
