@@ -66,7 +66,7 @@ class MockSynapse(Synapse):
 
     def extract_webhook_identifier(self):
         self.__print(self.extract_webhook_identifier.__name__, self.request)
-        return self.__get_mock_response(RequestType.EXTRACT_WEBHOOK_IDENTIFIER)
+        return 'MockWebhookID'
 
     def process_webhook(self):
         self.__print(self.process_webhook.__name__, self.request)
@@ -170,6 +170,16 @@ def test_process_webook_request():
     assert mock_event_data.data.name == 'MockRecord'
 
 
+def test_extract_webhook_identifier():
+    synapse_request = Request(type=RequestType.EXTRACT_WEBHOOK_IDENTIFIER,
+        connection=get_connection(),
+        body=WebhookRequest(body=json.dumps([{'key':'value'}]))).json()
+    synapse = MockSynapse(synapse_request)
+    resp = synapse.execute()
+    assert resp is not None
+    assert resp == 'MockWebhookID'
+
+
 def get_connection():
     authConfig=AuthConfig(endpoint='http://endpoint.com')
     connection = Connection(id='1', name='name', authConfig=authConfig, idFieldName='idfield', watermarkFieldName='watermarkfield', 
